@@ -1,3 +1,7 @@
+"""
+Some allowed configuration parameters - not meant to be directly called by the end user
+"""
+
 LOCATIONS = [
     None,
     'top',
@@ -26,7 +30,8 @@ COLORS = [
 BADGES = [
     'circle',
     'square',
-    'star'
+    'star',
+    'underline'
 ]
 
 WORD_LISTS = [
@@ -43,3 +48,13 @@ QUALIFIERS = [
     'ne',
     'nin'
 ]
+
+POSITIONS = [
+    'absolute',
+    'static'
+]
+
+STATIC_POSITIONS = [
+    'append',
+    'prepend'
+]
