@@ -1,32 +1,52 @@
+from typing import Union
 from aisquared.base import LOCATIONS, BaseObject
 
+
 class ImageRendering(BaseObject):
     """
     Object which dictates how to render images
+
+    Example usage:
+
+    >>> import aisquared
+    >>> my_obj = aisquared.config.rendering.ImageRendering()
+    >>> my_obj.to_dict()
+    {'className': 'ImageRendering',
+    'params': {'color': 'blue',
+    'thickness': '5',
+    'placement': 'bottomleft',
+    'includeProbability': False,
+    'badgeColor': 'white',
+    'fontColor': 'black',
+    'fontSize': '5',
+    'classes': None,
+    'thresholdKey': None,
+    'thresholdValue': None}}
+
     """
 
     def __init__(
         self,
-        color = 'blue',
-        thickness = '5px',
-        placement = LOCATIONS[-1],
-        include_probability = False,
-        badge_color = 'white',
-        font_color = 'black',
-        font_size = '5px',
-        classes = None,
-        confidence_threshold = None,
-        regression_threshold = None
+        color: str = 'blue',
+        thickness: str = '5',
+        placement: str = LOCATIONS[-1],
+        include_probability: bool = False,
+        badge_color: str = 'white',
+        font_color: str = 'black',
+        font_size: str = '5',
+        classes: list = None,
+        threshold_key: str = None,
+        threshold_value: Union[int, float] = None
     ):
         """
         Parameters
         ----------
         color : str (default 'blue')
             The color of the box around images
-        thickness : str (default '5px')
+        thickness : str (default '5')
             The thickness of the box around images
         placement : str (default 'bottomleft')
-            The placement of the predicted value in the box 
+            The placement of the predicted value in the box
             around images
         include_probability : bool (default False)
             Whether to render calculated probabilities
@@ -34,30 +54,31 @@ class ImageRendering(BaseObject):
             Background color of the text region
         font_color : str (default 'black')
             Color of the text
-        font_size : str (default '5px')
+        font_size : str (default '5')
             Text size
         classes : None or list (default None)
             If provided, list of classes that will be rendered
-        confidence_threshold : None or float (default None)
-            The threshold for rendering, if provided
-        regression_threshold : None or dict (default None)
-            Information for regression rendering, with 'filter' and 'value' keys
+        threshold_key : None or str (default None)
+            If provided, the key to use for thresholding
+        threshold_value : None or numeric (default None)
+            If provided with threshold_key, the value to use to threshold rendering
         """
         super().__init__()
         self.color = color
         self.thickness = thickness
         self.placement = placement
-        self.include_probability = include_probability  
+        self.include_probability = include_probability
         self.badge_color = badge_color
         self.font_color = font_color
         self.font_size = font_size
         self.classes = classes
-        self.confidence_threshold = confidence_threshold
-        self.regression_threshold = regression_threshold
+        self.threshold_key = threshold_key
+        self.threshold_value = threshold_value
 
     @property
     def color(self):
         return self._color
+
     @color.setter
     def color(self, value):
         self._color = value
@@ -65,6 +86,7 @@ class ImageRendering(BaseObject):
     @property
     def thickness(self):
         return self._thickness
+
     @thickness.setter
     def thickness(self, value):
         self._thickness = value
@@ -72,6 +94,7 @@ class ImageRendering(BaseObject):
     @property
     def placement(self):
         return self._placement
+
     @placement.setter
     def placement(self, value):
         if value not in LOCATIONS:
@@ -81,6 +104,7 @@ class ImageRendering(BaseObject):
     @property
     def include_probability(self):
         return self._include_probability
+
     @include_probability.setter
     def include_probability(self, value):
         self._include_probability = value
@@ -88,6 +112,7 @@ class ImageRendering(BaseObject):
     @property
     def badge_color(self):
         return self._badge_color
+
     @badge_color.setter
     def badge_color(self, value):
         self._badge_color = value
@@ -95,6 +120,7 @@ class ImageRendering(BaseObject):
     @property
     def font_color(self):
         return self._font_color
+
     @font_color.setter
     def font_color(self, value):
         self._font_color = value
@@ -102,47 +128,51 @@ class ImageRendering(BaseObject):
     @property
     def font_size(self):
         return self._font_size
+
     @font_size.setter
     def font_size(self, value):
         self._font_size = value
-    
+
     @property
     def classes(self):
         return self._classes
+
     @classes.setter
     def classes(self, value):
         self._classes = value
 
     @property
-    def confidence_threshold(self):
-        return self._confidence_threshold
-    @confidence_threshold.setter
-    def confidence_threshold(self, value):
-        self._confidence_threshold = value
+    def threshold_key(self):
+        return self._threshold_key
+
+    @threshold_key.setter
+    def threshold_key(self, value):
+        self._threshold_key = value
 
     @property
-    def regression_threshold(self):
-        return self._regression_threshold
-    @regression_threshold.setter
-    def regression_threshold(self, value):
-        self._regression_threshold = value
+    def threshold_value(self):
+        return self._threshold_value
 
-    def to_dict(self):
+    @threshold_value.setter
+    def threshold_value(self, value):
+        self._threshold_value = value
+
+    def to_dict(self) -> dict:
         """
         Get the configuration object as a dictionary
         """
         return {
-            'className' : 'ImageRendering',
-            'params' : {
-                'color' : self.color,
-                'thickness' : self.thickness,
-                'placement' : self.placement,
-                'includeProbability' : self.include_probability,
-                'badgeColor' : self.badge_color,
-                'fontColor' : self.font_color,
-                'fontSize' : self.font_size,
-                'classes' : self.classes,
-                'confidenceThreshold' : self.confidence_threshold,
-                'regressionThreshold' : self.regression_threshold
+            'className': 'ImageRendering',
+            'params': {
+                'color': self.color,
+                'thickness': self.thickness,
+                'placement': self.placement,
+                'includeProbability': self.include_probability,
+                'badgeColor': self.badge_color,
+                'fontColor': self.font_color,
+                'fontSize': self.font_size,
+                'classes': self.classes,
+                'thresholdKey': self.threshold_key,
+                'thresholdValue': self.threshold_value
             }
         }
